"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TreeView = void 0;
var _react = _interopRequireDefault(require("react"));
var _NodeList = _interopRequireDefault(require("./components/NodeList"));
var _helpers = require("./helpers");
var _global = require("./store/global.store");
var _reactNative = require("react-native");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const _TreeView = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  const {
    data,
    onCheck,
    onExpand,
    preselectedIds,
    treeFlashListProps,
    checkBoxViewStyleProps,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent
  } = props;
  const {
    expanded,
    updateExpanded,
    globalData,
    updateGlobalData,
    searchText,
    updatedSearchText,
    updatedSearchKeys,
    checked,
    cleanUpGlobalStore
  } = (0, _global.useStore)();
  _react.default.useImperativeHandle(ref, () => ({
    selectAll: _helpers.selectAll,
    unselectAll: _helpers.unselectAll,
    selectAllFiltered: _helpers.selectAllFiltered,
    unselectAllFiltered: _helpers.unselectAllFiltered,
    expandAll: _helpers.expandAll,
    collapseAll: _helpers.collapseAll,
    setSearchText
  }));
  function setSearchText(text) {
    let keys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ["name"];
    updatedSearchText(text);
    updatedSearchKeys(keys);
  }
  _react.default.useEffect(() => {
    updateGlobalData(data);
    (0, _helpers.initializeNodeMaps)(data, preselectedIds);
  }, [updateGlobalData, data, preselectedIds]);
  const getIds = _react.default.useCallback(node => {
    if (!node.children || node.children.length === 0) {
      return [node.id];
    } else {
      return [node.id, ...node.children.flatMap(item => getIds(item))];
    }
  }, []);
  _react.default.useEffect(() => {
    onCheck && onCheck(Array.from(checked));
  }, [onCheck, checked]);
  _react.default.useEffect(() => {
    onExpand && onExpand(Array.from(expanded));
  }, [onExpand, expanded]);
  _react.default.useEffect(() => {
    if (searchText) {
      _reactNative.InteractionManager.runAfterInteractions(() => {
        updateExpanded(new Set(globalData.flatMap(item => getIds(item))));
      });
    } else {
      _reactNative.InteractionManager.runAfterInteractions(() => {
        updateExpanded(new Set());
      });
    }
  }, [getIds, globalData, searchText, updateExpanded]);
  _react.default.useEffect(() => {
    return () => {
      cleanUpGlobalStore();
    };
  }, [cleanUpGlobalStore]);
  return /*#__PURE__*/_react.default.createElement(_NodeList.default, {
    treeFlashListProps: treeFlashListProps,
    checkBoxViewStyleProps: checkBoxViewStyleProps,
    CheckboxComponent: CheckboxComponent,
    ExpandCollapseIconComponent: ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
  });
});
const TreeView = /*#__PURE__*/_react.default.memo(_TreeView);
exports.TreeView = TreeView;
//# sourceMappingURL=TreeView.js.map